@@ -71,7 +71,7 @@ sub run($$)
     if (defined($DB::dbline[$line]) && 0 != $DB::dbline[$line]) {
         my $cop = 0;
         $cop = 0 + $DB::dbline[$line];
-        $m = sprintf "COP address: 0x%x.", $cop;
+        $m = sprintf "OP address: 0x%x.", $cop;
         $proc->msg($m);
     } else {
         $proc->msg("Line not showing as associated with code\n") 
