@@ -79,7 +79,8 @@ sub run($$)
     no warnings 'once';
     $DB::single = 0;
     $DB::fall_off_on_end = 1;
-    $self->{proc}->{interfaces} = [];
+    $proc->terminated();
+    $proc->{interfaces} = [];
     # No graceful way to stop threads...
     exit $exitrc;
 }
